# customer_rating_library/customer_rating_library.py

class CustomerRating:
    def __init__(self, maximum_rating=10):

        #This initializes the maximium rating value

        self.maximum_rating = maximum_rating

    def calculate_average_customer_rating(self, customer_ratings):

        """It calculates the average rating from the list of customer ratings 
           and return 0 if the list is empty."""
        
        if not customer_ratings:
            return 0
        return sum(customer_ratings) / len(customer_ratings)

    def convert_to_percentage(self, average_customer_rating):

        """" It converts the average rating(float) to percentage based on the maximum customer rating
             and returns the percentage of the rating"""

        return (average_customer_rating / self.maximum_rating) * 100



# setup.py
from setuptools import setup, find_packages

setup(
    name="customer_rating_library",
    version="0.3",
    packages=find_packages(),
    description="A library to calculate percentage for the customer ratings.",
    author="Deekshiya",
    author_email="deekshiya19@gmail.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
